Module ast

Module ast 

Structs

CasePattern
A single case pattern clause within a case statement.
ListItem
An item in a command list: a command with an optional trailing operator.
Node
A spanned AST node combining a NodeKind with its source Span.
Span
Source span representing a byte range in the original input.

Enums

ListOperator
Operator between commands in a list.
NodeKind
AST node representing all bash constructs.
PipeSep
Separator between commands in a pipeline.