pub struct Node {
pub kind: NodeKind,
pub span: Span,
}Fields
kind: NodeKindspan: SpanImplementations
Sourceimpl Node
impl Node
Sourcepub const fn new(kind: NodeKind, span: Span) -> Self
pub const fn new(kind: NodeKind, span: Span) -> Self
Creates a new node with the given kind and span.
Sourcepub const fn empty(kind: NodeKind) -> Self
pub const fn empty(kind: NodeKind) -> Self
Creates a node with an empty span (for synthetic or temporary nodes).
Sourcepub fn source_text<'a>(&self, source: &'a str) -> &'a str
pub fn source_text<'a>(&self, source: &'a str) -> &'a str
Extracts the source text for this node from the original source string.
Spans use character indices (matching Token.pos semantics).
Returns an empty string for synthetic nodes or invalid spans.